@@ -11,7 +11,7 @@
  */
 
 #include <rz_util.h>
-#include <ht_uu.h>
+#include <rz_util/ht_uu.h>
 #include <capstone/capstone.h>
 
 typedef struct rz_arm_it_context_t {
