@@ -127,7 +127,7 @@ static const char *delspc(const char *ptr) {
 static void rd_comma(const char **p) {
 	*p = delspc (*p);
 	if (**p != ',') {
-		eprintf ("`,' expected. Remainder of line: %s\n", *p);
+		RZ_LOG_ERROR("assembler: z80: `,' expected. Remainder of line: %s\n", *p);
 		return;
 	}
 	*p = delspc ((*p) + 1);
@@ -156,7 +156,7 @@ static int indx(const char **ptr, const char **list, int error, const char **exp
 	*ptr = delspc (*ptr);
 	if (!**ptr) {
 		if (error) {
-			eprintf ("unexpected end of line\n");
+			RZ_LOG_ERROR("assembler: z80: unexpected end of line\n");
 			return 0;
 		} else {
 			return 0;
@@ -208,7 +208,7 @@ static int indx(const char **ptr, const char **list, int error, const char **exp
 		comma++;
 		return i + 1;
 	}
-	// if (error) eprintf ("parse error. Remainder of line=%s\n", *ptr);
+	// if (error) RZ_LOG_ERROR("assembler: z80: parse error. Remainder of line=%s\n", *ptr);
 	return 0;
 }
 
@@ -233,7 +233,7 @@ static void readlabel(const char **p, int store) {
 		return;
 	}
 	if (pos == *p) {
-		eprintf ("`:' found without a label");
+		RZ_LOG_ERROR("assembler: z80: `:' found without a label");
 		return;
 	}
 	if (!store) {
@@ -244,7 +244,7 @@ static void readlabel(const char **p, int store) {
 	dummy = *p;
 	j = rd_label (&dummy, &i, &previous, sp, 0);
 	if (i || j) {
-		eprintf ("duplicate definition of label %s\n", *p);
+		RZ_LOG_ERROR("assembler: z80: duplicate definition of label %s\n", *p);
 		*p = c;
 		return;
 	}
@@ -733,7 +733,7 @@ static int rd_ldbcdehla(const char **p) {
 		int x;
 		x = 0xdd + 0x20 * (i > 12);
 		if (indexed && indexed != x) {
-			eprintf ("illegal use of index registers\n");
+			RZ_LOG_ERROR("assembler: z80: illegal use of index registers\n");
 			return 0;
 		}
 		indexed = x;
@@ -741,7 +741,7 @@ static int rd_ldbcdehla(const char **p) {
 	}
 	if (i > 8) {
 		if (indexed) {
-			eprintf ("illegal use of index registers\n");
+			RZ_LOG_ERROR("assembler: z80: illegal use of index registers\n");
 			return 0;
 		}
 		indexed = 0xDD + 0x20 * (i == 10);
@@ -861,7 +861,7 @@ static int assemble(const char *str, unsigned char *_obuf) {
 			}
 			if (has_argument (&ptr)) {
 				if (r != A) {
-					eprintf ("parse error before: %s\n", ptr);
+					RZ_LOG_ERROR("assembler: z80: parse error before: %s\n", ptr);
 					break;
 				}
 				if (!(r = rd_r (&ptr))) {
@@ -1405,7 +1405,7 @@ static int assemble(const char *str, unsigned char *_obuf) {
 			}
 			if (has_argument (&ptr)) {		/* SUB A,r ?  */
 				if (r != A) {
-					eprintf ("parse error before: %s\n", ptr);
+					RZ_LOG_ERROR("assembler: z80: parse error before: %s\n", ptr);
 					break;
 				}
 				if (!(r = rd_r (&ptr))) {
@@ -1436,7 +1436,7 @@ static int assemble(const char *str, unsigned char *_obuf) {
 					while (*ptr != quote) {
 						write_one_byte (rd_character (&ptr, NULL, 1), 0);
 						if (*ptr == 0) {
-							eprintf ("end of line in quoted string\n");
+							RZ_LOG_ERROR("assembler: z80: end of line in quoted string\n");
 							break;
 						}
 					}
@@ -1451,7 +1451,7 @@ static int assemble(const char *str, unsigned char *_obuf) {
 					continue;
 				}
 				if (*ptr != 0) {
-					eprintf ("junk in byte definition: %s\n", ptr);
+					RZ_LOG_ERROR("assembler: z80: junk in byte definition: %s\n", ptr);
 				}
 				break;
 			}
@@ -1459,7 +1459,7 @@ static int assemble(const char *str, unsigned char *_obuf) {
 		case Z80_DEFW:
 		case Z80_DW:
 			if (!rd_word (&ptr, ',')) {
-				eprintf ("No data for word definition\n");
+				RZ_LOG_ERROR("assembler: z80: No data for word definition\n");
 				break;
 			}
 			while (1) {
@@ -1469,7 +1469,7 @@ static int assemble(const char *str, unsigned char *_obuf) {
 				}
 				++ptr;
 				if (!rd_word (&ptr, ',')) {
-					eprintf ("Missing expression in defw\n");
+					RZ_LOG_ERROR("assembler: z80: Missing expression in defw\n");
 				}
 			}
 			break;
@@ -1477,7 +1477,7 @@ static int assemble(const char *str, unsigned char *_obuf) {
 		case Z80_DS:
 			r = rd_expr (&ptr, ',', NULL, sp, 1);
 			if (r < 0) {
-				eprintf ("ds should have its first argument >=0"
+				RZ_LOG_ERROR("assembler: z80: ds should have its first argument >=0"
 						" (not -0x%x)\n", -r);
 				break;
 			}
@@ -1501,21 +1501,21 @@ static int assemble(const char *str, unsigned char *_obuf) {
 		case Z80_IF:
 			break;
 		case Z80_ELSE:
-			eprintf ("else without if\n");
+			RZ_LOG_ERROR("assembler: z80: else without if\n");
 			break;
 		case Z80_ENDIF:
-			eprintf ("endif without if\n");
+			RZ_LOG_ERROR("assembler: z80: endif without if\n");
 			break;
 		case Z80_ENDM:
 			if (stack[sp].file) {
-				eprintf ("endm outside macro definition\n");
+				RZ_LOG_ERROR("assembler: z80: endm outside macro definition\n");
 			}
 			break;
 		case Z80_SEEK:
-			eprintf ("seek error\n");
+			RZ_LOG_ERROR("assembler: z80: seek error\n");
 			break;
 		default:
-			// eprintf ("command or comment expected (was %s)\n", ptr);
+			// RZ_LOG_ERROR("assembler: z80: command or comment expected (was %s)\n", ptr);
 			return 0;
 	}
 
