@@ -8,10 +8,14 @@
 #include <rz_asm.h>
 #include <cr16_disas.h>
 
-static int disassemble(RzAsm *a, RzAsmOp *op, const ut8 *buf, int len) {
-	struct cr16_cmd cmd;
+static int cr16_disassemble(RzAsm *a, RzAsmOp *op, const ut8 *buf, int len) {
+	struct cr16_cmd cmd = { 0 };
 	int ret = cr16_decode_command(buf, &cmd, len);
-	rz_strbuf_set(&op->buf_asm, sdb_fmt("%s %s", cmd.instr, cmd.operands));
+	if (ret > -1) {
+		rz_strbuf_initf(&op->buf_asm, "%s %s", cmd.instr, cmd.operands);
+	} else {
+		rz_asm_op_set_asm(op, "invalid");
+	}
 	return op->size = ret;
 }
 
@@ -22,7 +26,7 @@ RzAsmPlugin rz_asm_plugin_cr16 = {
 	.arch = "cr16",
 	.bits = 16,
 	.endian = RZ_SYS_ENDIAN_LITTLE,
-	.disassemble = &disassemble
+	.disassemble = &cr16_disassemble
 };
 
 #ifndef RZ_PLUGIN_INCORE
