@@ -4,8 +4,6 @@
 #include <rz_asm.h>
 #include <rz_lib.h>
 #include <capstone/capstone.h>
-static csh cd = 0;
-#include "cs_mnemonics.c"
 
 #ifdef CAPSTONE_TMS320C64X_H
 #define CAPSTONE_HAS_TMS320C64X 1
@@ -15,45 +13,54 @@ static csh cd = 0;
 #endif
 
 #if CAPSTONE_HAS_TMS320C64X
+#include "cs_helper.h"
+
+CAPSTONE_DEFINE_PLUGIN_FUNCTIONS(tms320c64x);
+
+static int tms320c64x_disassemble(RzAsm *a, RzAsmOp *op, const ut8 *buf, int len) {
+	CapstoneContext *ctx = (CapstoneContext *)a->plugin_data;
 
-static int disassemble(RzAsm *a, RzAsmOp *op, const ut8 *buf, int len) {
 	cs_insn *insn;
 	int n = -1, ret = -1;
-	int mode = 0;
 	if (op) {
 		memset(op, 0, sizeof(RzAsmOp));
 		op->size = 4;
 	}
-	if (cd != 0) {
-		cs_close(&cd);
+	if (ctx->omode != 0) {
+		cs_close(&ctx->handle);
+		ctx->omode = -1;
 	}
-	ret = cs_open(CS_ARCH_TMS320C64X, mode, &cd);
-	if (ret) {
-		goto fin;
+	if (!ctx->handle) {
+		ret = cs_open(CS_ARCH_TMS320C64X, 0, &ctx->handle);
+		if (ret) {
+			goto fin;
+		}
+		ctx->omode = 0;
+		cs_option(ctx->handle, CS_OPT_DETAIL, CS_OPT_OFF);
 	}
-	cs_option(cd, CS_OPT_DETAIL, CS_OPT_OFF);
 	if (!op) {
 		return 0;
 	}
-	n = cs_disasm(cd, buf, len, a->pc, 1, &insn);
+	n = cs_disasm(ctx->handle, buf, len, a->pc, 1, &insn);
 	if (n < 1) {
 		rz_asm_op_set_asm(op, "invalid");
 		op->size = 4;
 		ret = -1;
-		goto beach;
+		goto fin;
 	} else {
 		ret = 4;
 	}
 	if (insn->size < 1) {
-		goto beach;
+		goto fin;
 	}
 	op->size = insn->size;
-	rz_asm_op_set_asm(op, sdb_fmt("%s%s%s", insn->mnemonic, insn->op_str[0] ? " " : "", insn->op_str));
-	rz_str_replace_char(rz_strbuf_get(&op->buf_asm), '%', 0);
-	rz_str_case(rz_strbuf_get(&op->buf_asm), false);
+	rz_asm_op_setf_asm(op, "%s%s%s", insn->mnemonic, insn->op_str[0] ? " " : "", insn->op_str);
+	char *str = rz_asm_op_get_asm(op);
+	if (str) {
+		rz_str_replace_char(str, '%', 0);
+		rz_str_case(str, false);
+	}
 	cs_free(insn, n);
-beach:
-// cs_close (&cd);
 fin:
 	return ret;
 }
@@ -65,8 +72,10 @@ RzAsmPlugin rz_asm_plugin_tms320c64x = {
 	.arch = "tms320c64x",
 	.bits = 32,
 	.endian = RZ_SYS_ENDIAN_BIG | RZ_SYS_ENDIAN_LITTLE,
-	.disassemble = &disassemble,
-	.mnemonics = mnemonics
+	.init = tms320c64x_init,
+	.fini = tms320c64x_fini,
+	.disassemble = &tms320c64x_disassemble,
+	.mnemonics = tms320c64x_mnemonics,
 };
 
 #else
@@ -78,7 +87,6 @@ RzAsmPlugin rz_asm_plugin_tms320c64x = {
 	.arch = "tms320c64x",
 	.bits = 32,
 	.endian = RZ_SYS_ENDIAN_LITTLE,
-	.mnemonics = mnemonics
 };
 
 #endif
