@@ -6,7 +6,7 @@
 #define RZ_BIN_FORMAT_DYLDCACHE_H
 
 #include <rz_util.h>
-#include <set.h>
+#include <rz_util/set.h>
 
 #define RZ_BIN_MACH064 1
 
@@ -233,6 +233,7 @@ typedef struct rz_dyldcache_t {
 	RzDyldLocSym *locsym;
 	objc_cache_opt_info *oi;
 	bool objc_opt_info_loaded;
+	ut32 unk_local_n;
 } RzDyldCache;
 
 RZ_API bool rz_dyldcache_check_magic(const char *magic);
@@ -243,7 +244,7 @@ RZ_API RZ_NONNULL const char *rz_dyldcache_get_type_str(RzDyldCache *cache);
 RZ_API ut64 rz_dyldcache_va2pa(RzDyldCache *cache, uint64_t vaddr, ut32 *offset, ut32 *left);
 RZ_API ut64 rz_dyldcache_get_slide(RzDyldCache *cache);
 RZ_API objc_cache_opt_info *rz_dyldcache_get_objc_opt_info(RzBinFile *bf, RzDyldCache *cache);
-RZ_API void rz_dyldcache_symbols_from_locsym(RzDyldCache *cache, RzDyldBinImage *bin, RzList /*<RzBinSymbol *>*/ *symbols, SetU *hash);
+RZ_API void rz_dyldcache_symbols_from_locsym(RzDyldCache *cache, RzDyldBinImage *bin, RzPVector /*<RzBinSymbol *>*/ *symbols, SetU *hash);
 
 RZ_API RzBuffer *rz_dyldcache_new_rebasing_buf(RzDyldCache *cache);
 RZ_API bool rz_dyldcache_needs_rebasing(RzDyldCache *cache);
