@@ -83,7 +83,7 @@ static RzBinInfo *info(RzBinFile *bf) {
 	return bin_info_obj->general_info;
 }
 
-static RzList /*<RzBinSection *>*/ *sections(RzBinFile *bf) {
+static RzPVector /*<RzBinSection *>*/ *sections(RzBinFile *bf) {
 	if (!bf) {
 		return NULL;
 	}
@@ -92,10 +92,10 @@ static RzList /*<RzBinSection *>*/ *sections(RzBinFile *bf) {
 		return NULL;
 	}
 
-	return rz_list_clone(bin_info_obj->section_list);
+	return rz_pvector_clone(bin_info_obj->section_vec);
 }
 
-static RzList /*<RzBinSymbol *>*/ *symbols(RzBinFile *bf) {
+static RzPVector /*<RzBinSymbol *>*/ *symbols(RzBinFile *bf) {
 	if (!bf) {
 		return NULL;
 	}
@@ -103,8 +103,13 @@ static RzList /*<RzBinSymbol *>*/ *symbols(RzBinFile *bf) {
 	if (!bin_info_obj) {
 		return NULL;
 	}
-
-	return rz_list_clone(bin_info_obj->symbol_list);
+	RzListIter *iter;
+	RzBinSymbol *sym;
+	RzPVector *vec = rz_pvector_new(NULL);
+	rz_list_foreach (bin_info_obj->symbol_list, iter, sym) {
+		rz_pvector_push(vec, sym);
+	}
+	return vec;
 }
 
 static RzList /*<RzBinAddr *>*/ *entries(RzBinFile *bf) {
@@ -119,7 +124,7 @@ static RzList /*<RzBinAddr *>*/ *entries(RzBinFile *bf) {
 	return rz_list_clone(bin_info_obj->entry_list);
 }
 
-static RzList /*<RzBinString *>*/ *strings(RzBinFile *bf) {
+static RzPVector /*<RzBinString *>*/ *strings(RzBinFile *bf) {
 	if (!bf) {
 		return NULL;
 	}
@@ -128,7 +133,13 @@ static RzList /*<RzBinString *>*/ *strings(RzBinFile *bf) {
 		return NULL;
 	}
 
-	return rz_list_clone(bin_info_obj->string_list);
+	RzListIter *iter;
+	RzBinString *bstr;
+	RzPVector *pvec = rz_pvector_new((RzPVectorFree)bin_info_obj->string_list->free);
+	rz_list_foreach (bin_info_obj->string_list, iter, bstr) {
+		rz_pvector_push(pvec, bstr);
+	}
+	return pvec;
 }
 
 static void destroy(RzBinFile *bf) {
