@@ -252,7 +252,7 @@ RZ_API char *rz_cons_hud(RzList /*<char *>*/ *list, const char *prompt) {
 		rz_list_free(filtered_list);
 #endif
 		rz_cons_visual_flush();
-		(void)rz_line_readline();
+		(void)rz_line_readline(I(line));
 		rz_str_ncpy(user_input, I(line)->buffer.data, HUD_BUF_SIZE); // to search
 
 		if (!hud->activate) {
