@@ -53,11 +53,12 @@ static void loadGP(RzCore *core) {
 	}
 }
 
-static RZ_OWN RzList /*<RzBinSection *>*/ *__save_old_sections(RzCore *core) {
-	RzList *sections = rz_bin_get_sections(core->bin);
-	RzListIter *it;
+static RZ_OWN RzPVector /*<RzBinSection *>*/ *__save_old_sections(RzCore *core) {
+	RzBinObject *obj = rz_bin_cur_object(core->bin);
+	const RzPVector *sections = obj ? rz_bin_object_get_sections_all(obj) : NULL;
+	void **it;
 	RzBinSection *sec;
-	RzList *old_sections = rz_list_new();
+	RzPVector *old_sections = rz_pvector_new(NULL);
 
 	// Return an empty list
 	if (!sections) {
@@ -65,8 +66,9 @@ static RZ_OWN RzList /*<RzBinSection *>*/ *__save_old_sections(RzCore *core) {
 		return old_sections;
 	}
 
-	old_sections->free = sections->free;
-	rz_list_foreach (sections, it, sec) {
+	old_sections->v.free_user = sections->v.free_user;
+	rz_pvector_foreach (sections, it) {
+		sec = *it;
 		RzBinSection *old_sec = RZ_NEW0(RzBinSection);
 		if (!old_sec) {
 			break;
@@ -74,14 +76,14 @@ static RZ_OWN RzList /*<RzBinSection *>*/ *__save_old_sections(RzCore *core) {
 		*old_sec = *sec;
 		old_sec->name = strdup(sec->name);
 		old_sec->format = NULL;
-		rz_list_append(old_sections, old_sec);
+		rz_pvector_push(old_sections, old_sec);
 	}
 	return old_sections;
 }
 
 struct __rebase_struct {
 	RzCore *core;
-	RzList /*<RzBinSection *>*/ *old_sections;
+	RzPVector /*<RzBinSection *>*/ *old_sections;
 	ut64 old_base;
 	ut64 diff;
 	int type;
@@ -93,10 +95,11 @@ struct __rebase_struct {
 static bool __rebase_flags(RzFlagItem *flag, void *user) {
 	struct __rebase_struct *reb = user;
 	ut64 old_base = reb->old_base;
-	RzListIter *it;
+	void **it;
 	RzBinSection *sec;
 	// Only rebase flags that were in the rebased sections, otherwise it will take too long
-	rz_list_foreach (reb->old_sections, it, sec) {
+	rz_pvector_foreach (reb->old_sections, it) {
+		sec = *it;
 		if (__is_inside_section(flag->offset, sec)) {
 			rz_flag_set(reb->core->flags, flag->name, flag->offset + reb->diff, flag->size);
 			break;
@@ -120,8 +123,8 @@ static bool __rebase_xrefs(void *user, const ut64 k, const void *v) {
 	return true;
 }
 
-static void __rebase_everything(RzCore *core, RzList /*<RzBinSection *>*/ *old_sections, ut64 old_base) {
-	RzListIter *it, *itit, *ititit;
+static void __rebase_everything(RzCore *core, RzPVector /*<RzBinSection *>*/ *old_sections, ut64 old_base) {
+	RzListIter *it, *ititit;
 	RzAnalysisFunction *fcn;
 	ut64 new_base = core->bin->cur->o->baddr_shift;
 	RzBinSection *old_section;
@@ -131,7 +134,9 @@ static void __rebase_everything(RzCore *core, RzList /*<RzBinSection *>*/ *old_s
 	}
 	// FUNCTIONS
 	rz_list_foreach (core->analysis->fcns, it, fcn) {
-		rz_list_foreach (old_sections, itit, old_section) {
+		void **iter;
+		rz_pvector_foreach (old_sections, iter) {
+			old_section = *iter;
 			if (!__is_inside_section(fcn->addr, old_section)) {
 				continue;
 			}
@@ -230,7 +235,7 @@ RZ_API void rz_core_file_reopen_remote_debug(RzCore *core, const char *uri, ut64
 	}
 
 	core->dbg->main_arena_resolved = false;
-	RzList *old_sections = __save_old_sections(core);
+	RzPVector *old_sections = __save_old_sections(core);
 	ut64 old_base = core->bin->cur->o->baddr_shift;
 	int bits = core->rasm->bits;
 	rz_config_set_i(core->config, "asm.bits", bits);
@@ -254,14 +259,14 @@ RZ_API void rz_core_file_reopen_remote_debug(RzCore *core, const char *uri, ut64
 		rz_core_bin_load(core, uri, addr);
 	} else {
 		RZ_LOG_ERROR("Cannot open file '%s'\n", uri);
-		rz_list_free(old_sections);
+		rz_pvector_free(old_sections);
 		return;
 	}
 	rz_core_block_read(core);
 	if (rz_config_get_i(core->config, "dbg.rebase")) {
 		__rebase_everything(core, old_sections, old_base);
 	}
-	rz_list_free(old_sections);
+	rz_pvector_free(old_sections);
 	rz_core_seek_to_register(core, "PC", false);
 }
 
@@ -297,7 +302,7 @@ RZ_API void rz_core_file_reopen_debug(RzCore *core, const char *args) {
 		return;
 	}
 	core->dbg->main_arena_resolved = false;
-	RzList *old_sections = __save_old_sections(core);
+	RzPVector *old_sections = __save_old_sections(core);
 	ut64 old_base = core->bin->cur->o->baddr_shift;
 	int bits = core->rasm->bits;
 	char *bin_abspath = rz_file_abspath(binpath);
@@ -312,7 +317,7 @@ RZ_API void rz_core_file_reopen_debug(RzCore *core, const char *args) {
 	if (rz_config_get_i(core->config, "dbg.rebase")) {
 		__rebase_everything(core, old_sections, old_base);
 	}
-	rz_list_free(old_sections);
+	rz_pvector_free(old_sections);
 	rz_core_seek_to_register(core, "PC", false);
 	free(bin_abspath);
 	free(escaped_path);
@@ -537,17 +542,18 @@ RZ_API void rz_core_sysenv_end(RzCore *core) {
 }
 
 RZ_API void rz_core_sysenv_begin(RzCore *core) {
+	char tmpbuf[64];
 	// This will be deprecated when moving the . commands to newshell
 	RzIODesc *desc = core->file ? rz_io_desc_get(core->io, core->file->fd) : NULL;
 	rz_sys_setenv("RZ_BIN_PDBSERVER", rz_config_get(core->config, "pdb.server"));
 	if (desc && desc->name) {
 		rz_sys_setenv("RZ_FILE", desc->name);
-		rz_sys_setenv("RZ_SIZE", sdb_fmt("%" PFMT64d, rz_io_desc_size(desc)));
+		rz_sys_setenv("RZ_SIZE", rz_strf(tmpbuf, "%" PFMT64d, rz_io_desc_size(desc)));
 	}
-	rz_sys_setenv("RZ_OFFSET", sdb_fmt("%" PFMT64d, core->offset));
-	rz_sys_setenv("RZ_XOFFSET", sdb_fmt("0x%08" PFMT64x, core->offset));
+	rz_sys_setenv("RZ_OFFSET", rz_strf(tmpbuf, "%" PFMT64d, core->offset));
+	rz_sys_setenv("RZ_XOFFSET", rz_strf(tmpbuf, "0x%08" PFMT64x, core->offset));
 	rz_sys_setenv("RZ_ENDIAN", core->rasm->big_endian ? "big" : "little");
-	rz_sys_setenv("RZ_BSIZE", sdb_fmt("%d", core->blocksize));
+	rz_sys_setenv("RZ_BSIZE", rz_strf(tmpbuf, "%d", core->blocksize));
 
 	// dump current config file so other r2 tools can use the same options
 	char *config_sdb_path = NULL;
@@ -693,13 +699,7 @@ static bool core_file_do_load_for_debug(RzCore *r, ut64 baseaddr, const char *fi
 	rz_core_bin_apply_all_info(r, binfile);
 	rz_debug_reg_profile_sync(r->dbg);
 	plugin = rz_bin_file_cur_plugin(binfile);
-	if (plugin && !strcmp(plugin->name, "any")) {
-		// set use of raw strings
-		// rz_config_set_i (r->config, "io.va", false);
-		// get bin.minstr
-		r->bin->minstrlen = rz_config_get_i(r->config, "bin.minstr");
-		r->bin->maxstrbuf = rz_config_get_i(r->config, "bin.maxstrbuf");
-	} else if (binfile) {
+	if (!(plugin && !strcmp(plugin->name, "any")) && binfile) {
 		RzBinObject *obj = rz_bin_cur_object(r->bin);
 		RzBinInfo *info = obj ? obj->info : NULL;
 		if (plugin && info) {
@@ -731,11 +731,7 @@ static bool core_file_do_load_for_io_plugin(RzCore *r, ut64 baseaddr, ut64 loada
 	if (cf) {
 		rz_pvector_push(&cf->binfiles, binfile);
 	}
-	if (rz_core_bin_apply_all_info(r, binfile)) {
-		if (!r->analysis->sdb_cc->path) {
-			RZ_LOG_WARN("No calling convention defined for this file, analysis may be inaccurate.\n");
-		}
-	}
+	rz_core_bin_apply_all_info(r, binfile);
 	plugin = rz_bin_file_cur_plugin(binfile);
 	if (plugin && !strcmp(plugin->name, "any")) {
 		RzBinObject *obj = rz_bin_cur_object(r->bin);
@@ -744,12 +740,7 @@ static bool core_file_do_load_for_io_plugin(RzCore *r, ut64 baseaddr, ut64 loada
 			return false;
 		}
 		info->bits = r->rasm->bits;
-		// set use of raw strings
 		rz_core_bin_set_arch_bits(r, binfile->file, info->arch, info->bits);
-		// rz_config_set_i (r->config, "io.va", false);
-		// get bin.minstr
-		r->bin->minstrlen = rz_config_get_i(r->config, "bin.minstr");
-		r->bin->maxstrbuf = rz_config_get_i(r->config, "bin.maxstrbuf");
 	} else if (binfile) {
 		RzBinObject *obj = rz_bin_cur_object(r->bin);
 		RzBinInfo *info = obj ? obj->info : NULL;
@@ -892,10 +883,11 @@ static bool resolve_import_cb(RzCoreLinkData *ld, RzIODesc *desc, ut32 id) {
 	if (!bf) {
 		return true;
 	}
-	RzListIter *iter;
+	void **iter;
 	RzBinSymbol *sym;
-	RzList *symbols = rz_bin_file_get_symbols(bf);
-	rz_list_foreach (symbols, iter, sym) {
+	RzPVector *symbols = rz_bin_file_get_symbols(bf);
+	rz_pvector_foreach (symbols, iter) {
+		sym = *iter;
 		if (!strcmp(sym->name, ld->name)) {
 			ld->addr = sym->vaddr;
 			return false;
@@ -967,8 +959,6 @@ RZ_API bool rz_core_bin_load(RZ_NONNULL RzCore *r, RZ_NULLABLE const char *filen
 		return false;
 	}
 
-	r->bin->minstrlen = rz_config_get_i(r->config, "bin.minstr");
-	r->bin->maxstrbuf = rz_config_get_i(r->config, "bin.maxstrbuf");
 	if (is_io_load) {
 		// TODO? necessary to restore the desc back?
 		// Fix to select pid before trying to load the binary
@@ -1016,11 +1006,6 @@ RZ_API bool rz_core_bin_load(RZ_NONNULL RzCore *r, RZ_NULLABLE const char *filen
 			} else {
 				rz_io_map_new(r->io, desc->fd, desc->perm, 0, laddr, rz_io_desc_size(desc));
 			}
-			// set use of raw strings
-			// rz_config_set_i (r->config, "io.va", false);
-			// get bin.minstr
-			r->bin->minstrlen = rz_config_get_i(r->config, "bin.minstr");
-			r->bin->maxstrbuf = rz_config_get_i(r->config, "bin.maxstrbuf");
 		} else if (binfile) {
 			RzBinObject *obj = rz_bin_cur_object(r->bin);
 			if (obj) {
@@ -1029,7 +1014,7 @@ RZ_API bool rz_core_bin_load(RZ_NONNULL RzCore *r, RZ_NULLABLE const char *filen
 					rz_config_set_i(r->config, "io.va", 0);
 				}
 				// workaround to map correctly malloc:// and raw binaries
-				if (rz_io_desc_is_dbg(desc) || (rz_list_empty(obj->maps) || !va)) {
+				if (rz_io_desc_is_dbg(desc) || (rz_pvector_empty(obj->maps) || !va)) {
 					rz_io_map_new(r->io, desc->fd, desc->perm, 0, laddr, rz_io_desc_size(desc));
 				}
 				RzBinInfo *info = obj->info;
@@ -1060,16 +1045,21 @@ RZ_API bool rz_core_bin_load(RZ_NONNULL RzCore *r, RZ_NULLABLE const char *filen
 	}
 	if (rz_config_get_b(r->config, "bin.libs")) {
 		const char *lib;
-		RzListIter *iter;
-		RzList *libs = rz_bin_get_libs(r->bin);
-		rz_list_foreach (libs, iter, lib) {
-			if (file_is_loaded(r, lib)) {
-				continue;
-			}
-			RZ_LOG_INFO("Opening library %s\n", lib);
-			ut64 baddr = rz_io_map_location(r->io, 0x200000);
-			if (baddr != UT64_MAX) {
-				rz_core_file_loadlib(r, lib, baddr);
+		void **iter;
+
+		RzBinObject *o = rz_bin_cur_object(r->bin);
+		const RzPVector *libs = rz_bin_object_get_libs(o);
+		if (libs) {
+			rz_pvector_foreach (libs, iter) {
+				lib = *iter;
+				if (file_is_loaded(r, lib)) {
+					continue;
+				}
+				RZ_LOG_INFO("Opening library %s\n", lib);
+				ut64 baddr = rz_io_map_location(r->io, 0x200000);
+				if (baddr != UT64_MAX) {
+					rz_core_file_loadlib(r, lib, baddr);
+				}
 			}
 		}
 
@@ -1081,8 +1071,11 @@ RZ_API bool rz_core_bin_load(RZ_NONNULL RzCore *r, RZ_NULLABLE const char *filen
 		rz_config_set_b(r->config, "bin.at", true);
 		RZ_LOG_INFO("Linking imports...\n");
 		RzBinImport *imp;
-		RzList *imports = rz_bin_get_imports(r->bin);
-		rz_list_foreach (imports, iter, imp) {
+		RzBinObject *bin_obj = rz_bin_cur_object(r->bin);
+		const RzPVector *imports = rz_bin_object_get_imports(bin_obj);
+		void **vec_iter;
+		rz_pvector_foreach (imports, vec_iter) {
+			imp = *vec_iter;
 			char *name = rz_str_newf("sym.imp.%s", imp->name);
 			rz_name_filter(name + 8, strlen(name + 8) + 1, true);
 
@@ -1619,7 +1612,7 @@ RZ_API void rz_core_io_file_open(RZ_NONNULL RzCore *core, int fd) {
 	// Backup the baddr and sections that were already rebased to
 	// revert the rebase after the debug session is closed
 	ut64 orig_baddr = core->bin->cur->o->baddr_shift;
-	RzList *orig_sections = __save_old_sections(core);
+	RzPVector *orig_sections = __save_old_sections(core);
 
 	rz_bin_file_delete_all(core->bin);
 	rz_io_close_all(core->io);
@@ -1627,21 +1620,21 @@ RZ_API void rz_core_io_file_open(RZ_NONNULL RzCore *core, int fd) {
 
 	RzCoreFile *cfile = rz_core_file_open(core, file, RZ_PERM_R, 0);
 	if (!cfile) {
-		rz_list_free(orig_sections);
+		rz_pvector_free(orig_sections);
 		RZ_LOG_ERROR("Cannot open file '%s'\n", file);
 		return;
 	}
 	core->num->value = cfile->fd;
 	// If no baddr defined, use the one provided by the file
 	if (!rz_core_bin_load(core, file, UT64_MAX)) {
-		rz_list_free(orig_sections);
+		rz_pvector_free(orig_sections);
 		RZ_LOG_ERROR("Cannot load binary info of '%s'.\n", file);
 		return;
 	}
 	rz_core_block_read(core);
 
 	__rebase_everything(core, orig_sections, orig_baddr);
-	rz_list_free(orig_sections);
+	rz_pvector_free(orig_sections);
 	free(file);
 }
 
