@@ -9,7 +9,7 @@
 
 RZ_IPI RzCmdStatus rz_history_list_or_exec_handler(RzCore *core, int argc, const char **argv) {
 	if (argc == 1) {
-		rz_line_hist_list();
+		rz_line_hist_list(core->cons->line);
 		return RZ_CMD_STATUS_OK;
 	}
 
@@ -19,7 +19,7 @@ RZ_IPI RzCmdStatus rz_history_list_or_exec_handler(RzCore *core, int argc, const
 		return RZ_CMD_STATUS_ERROR;
 	}
 
-	const char *cmd = rz_line_hist_get(index);
+	const char *cmd = rz_line_hist_get(core->cons->line, index);
 	if (!cmd) {
 		RZ_LOG_ERROR("cannot find command with index %d.\n", index);
 		return RZ_CMD_STATUS_ERROR;
@@ -30,13 +30,13 @@ RZ_IPI RzCmdStatus rz_history_list_or_exec_handler(RzCore *core, int argc, const
 }
 
 RZ_IPI RzCmdStatus rz_history_clear_handler(RzCore *core, int argc, const char **argv) {
-	rz_line_hist_free();
+	rz_line_hist_free(core->cons->line);
 	return RZ_CMD_STATUS_OK;
 }
 
 RZ_IPI RzCmdStatus rz_history_save_handler(RzCore *core, int argc, const char **argv) {
 	char *history = rz_path_home_history();
-	rz_line_hist_save(history);
+	rz_line_hist_save(core->cons->line, history);
 	free(history);
 	return RZ_CMD_STATUS_OK;
 }
