@@ -48,7 +48,7 @@ static void loadSystemPlugins(RzCore *core, int where) {
 	}
 	if (where & RZ_CORE_LOADLIBS_ENV) {
 		char *p = rz_sys_getenv(RZ_LIB_ENV);
-		if (p && *p) {
+		if (RZ_STR_ISNOTEMPTY(p)) {
 			rz_lib_opendir(core->lib, p, false);
 		}
 		free(p);
@@ -63,6 +63,13 @@ static void loadSystemPlugins(RzCore *core, int where) {
 		rz_lib_opendir(core->lib, spd, false);
 		free(spd);
 	}
+	if (where & RZ_CORE_LOADLIBS_EXTRA) {
+		char *epd = rz_path_extra(RZ_PLUGINS);
+		if (epd) {
+			rz_lib_opendir(core->lib, epd, false);
+		}
+		free(epd);
+	}
 #endif
 }
 
