@@ -609,16 +609,17 @@ static void debug_dmp_set_i386_registers(RzReg *reg, struct context_type_i386 *c
 static void debug_dmp_set_current_context(WindCtx *ctx, RzReg *reg, ut8 *buf) {
 	if (ctx->is_arm && ctx->is_64bit) {
 		// ARM 64
-		return debug_dmp_set_arm64_registers(reg, (struct context_type_arm64 *)buf);
+		debug_dmp_set_arm64_registers(reg, (struct context_type_arm64 *)buf);
 	} else if (ctx->is_arm && !ctx->is_64bit) {
 		// ARM 32
-		return debug_dmp_set_arm32_registers(reg, (struct context_type_arm *)buf);
+		debug_dmp_set_arm32_registers(reg, (struct context_type_arm *)buf);
 	} else if (ctx->is_64bit) {
 		// AMD 64
-		return debug_dmp_set_amd64_registers(reg, (struct context_type_amd64 *)buf);
+		debug_dmp_set_amd64_registers(reg, (struct context_type_amd64 *)buf);
+	} else {
+		// i386
+		debug_dmp_set_i386_registers(reg, (struct context_type_i386 *)buf);
 	}
-	// i386
-	return debug_dmp_set_i386_registers(reg, (struct context_type_i386 *)buf);
 }
 
 static size_t debug_dmp_get_current_context_size(WindCtx *ctx) {
@@ -842,7 +843,7 @@ static bool rz_debug_dmp_kill(RzDebug *dbg, int pid, int tid, int sig) {
 	return true;
 }
 
-static int is_pc_inside_windmodule(const struct context_type_amd64 *context, const void *list_data) {
+static int is_pc_inside_windmodule(const struct context_type_amd64 *context, const void *list_data, void *user) {
 	const ut64 pc = context->rip;
 	const WindModule *module = list_data;
 	return !(pc >= module->addr && pc < (module->addr + module->size));
@@ -868,7 +869,7 @@ RzList /*<RzDebugFrame *>*/ *rz_debug_dmp_frames(RzDebug *dbg, ut64 at) {
 			if (!modules) {
 				modules = dmp_get_modules(ctx);
 			}
-			RzListIter *it = rz_list_find(modules, &context, (RzListComparator)is_pc_inside_windmodule);
+			RzListIter *it = rz_list_find(modules, &context, (RzListComparator)is_pc_inside_windmodule, NULL);
 			if (!it) {
 				break;
 			}
