@@ -28,18 +28,18 @@ static int rz_debug_winkd_reg_write(RZ_BORROW RZ_NONNULL RzDebug *dbg, int type,
 	if (kdctx->windctx.is_arm) {
 		if (kdctx->windctx.is_64bit) {
 			const struct context_type_arm64 *ctx = (void *)buf;
-			flags = ctx->ContextFlags;
+			flags = rz_read_le32(&ctx->ContextFlags);
 		} else {
 			const struct context_type_arm *ctx = (void *)buf;
-			flags = ctx->context_flags;
+			flags = rz_read_le32(&ctx->context_flags);
 		}
 	} else {
 		if (kdctx->windctx.is_64bit) {
 			const struct context_type_amd64 *ctx = (void *)buf;
-			flags = ctx->context_flags;
+			flags = rz_read_le32(&ctx->context_flags);
 		} else {
 			const struct context_type_i386 *ctx = (void *)buf;
-			flags = ctx->context_flags;
+			flags = rz_read_le32(&ctx->context_flags);
 		}
 	}
 	return winkd_write_reg(kdctx, flags, buf, size);
@@ -266,7 +266,7 @@ static bool rz_debug_winkd_init(RZ_BORROW RZ_NONNULL RzDebug *dbg, void **user)
 	return true;
 }
 
-static RzList *rz_debug_winkd_pids(RZ_BORROW RZ_NONNULL RzDebug *dbg, int pid) {
+static RzList /*<RzDebugPid *>*/ *rz_debug_winkd_pids(RZ_BORROW RZ_NONNULL RzDebug *dbg, int pid) {
 	if (!kdctx || !kdctx->desc || !kdctx->syncd) {
 		return NULL;
 	}
@@ -323,7 +323,7 @@ static int rz_debug_winkd_select(RZ_BORROW RZ_NONNULL RzDebug *dbg, int pid, int
 	return true;
 }
 
-static RzList *rz_debug_winkd_threads(RZ_BORROW RZ_NONNULL RzDebug *dbg, int pid) {
+static RzList /*<RzDebugPid *>*/ *rz_debug_winkd_threads(RZ_BORROW RZ_NONNULL RzDebug *dbg, int pid) {
 	if (!kdctx || !kdctx->desc || !kdctx->syncd) {
 		return NULL;
 	}
@@ -355,7 +355,7 @@ static RzList *rz_debug_winkd_threads(RZ_BORROW RZ_NONNULL RzDebug *dbg, int pid
 	return ret;
 }
 
-static RzList *rz_debug_winkd_modules(RZ_BORROW RZ_NONNULL RzDebug *dbg) {
+static RzList /*<RzDebugMap *>*/ *rz_debug_winkd_modules(RZ_BORROW RZ_NONNULL RzDebug *dbg) {
 	if (!kdctx || !kdctx->desc || !kdctx->syncd) {
 		return NULL;
 	}
@@ -386,7 +386,7 @@ static RzList *rz_debug_winkd_modules(RZ_BORROW RZ_NONNULL RzDebug *dbg) {
 #include "native/bt/windows-x64.c"
 #include "native/bt/generic-all.c"
 
-static RzList *rz_debug_winkd_frames(RZ_BORROW RZ_NONNULL RzDebug *dbg, ut64 at) {
+static RzList /*<RzDebugFrame *>*/ *rz_debug_winkd_frames(RZ_BORROW RZ_NONNULL RzDebug *dbg, ut64 at) {
 	if (!kdctx || !kdctx->desc || !kdctx->syncd) {
 		return NULL;
 	}
@@ -400,7 +400,7 @@ static RzList *rz_debug_winkd_frames(RZ_BORROW RZ_NONNULL RzDebug *dbg, ut64 at)
 	return ret;
 }
 
-static RzList *rz_debug_winkd_maps(RZ_BORROW RZ_NONNULL RzDebug *dbg) {
+static RzList /*<RzDebugMap *>*/ *rz_debug_winkd_maps(RZ_BORROW RZ_NONNULL RzDebug *dbg) {
 	RzList *maps = winkd_list_maps(&kdctx->windctx);
 	RzListIter *it;
 	WindMap *m;
