@@ -64,9 +64,10 @@ static void addr_to_string(struct sockaddr_storage *ss, char *buffer, int buflen
 
 int bsd_handle_signals(RzDebug *dbg) {
 #if __KFBSD__ || __NetBSD__
+	siginfo_t siginfo;
+#if __KFBSD__
 	// Trying to figure out a bit by the signal
 	struct ptrace_lwpinfo linfo = { 0 };
-	siginfo_t siginfo;
 	int ret = ptrace(PT_LWPINFO, dbg->pid, (char *)&linfo, sizeof(linfo));
 	if (ret == -1) {
 		if (errno == ESRCH) {
@@ -83,7 +84,6 @@ int bsd_handle_signals(RzDebug *dbg) {
 		return 0;
 	}
 
-#if __KFBSD__
 	siginfo = linfo.pl_siginfo;
 #else
 	struct ptrace_siginfo sinfo = { 0 };
@@ -108,6 +108,13 @@ int bsd_handle_signals(RzDebug *dbg) {
 	case SIGSEGV:
 		dbg->reason.type = RZ_DEBUG_REASON_SEGFAULT;
 		break;
+#if __NetBSD__
+	case SIGTRAP:
+		if (siginfo.si_code == TRAP_BRKPT) {
+			dbg->reason.type = RZ_DEBUG_REASON_BREAKPOINT;
+		}
+		break;
+#endif
 	}
 
 	return 0;
@@ -139,7 +146,7 @@ int bsd_reg_write(RzDebug *dbg, int type, const ut8 *buf, int size) {
 bool bsd_generate_corefile(RzDebug *dbg, char *path, RzBuffer *dest) {
 #if defined(__NetBSD__)
 	return ptrace(PT_DUMPCORE, dbg->pid, path, strlen(path)) != -1;
-#elif defined(__FreeBSD__) && __FreeBSD_version >= 1400030
+#elif defined(__FreeBSD__) && __FreeBSD_version >= 1302000
 	struct ptrace_coredump pc = { .pc_fd = dest->fd, .pc_flags = PC_ALL, .pc_limit = 0 };
 	return ptrace(PT_COREDUMP, dbg->pid, (void *)&pc, sizeof(pc)) != -1;
 #else
@@ -211,16 +218,19 @@ RzDebugInfo *bsd_info(RzDebug *dbg, const char *arg) {
 		rdi->gid = kp->p__pgid;
 		rdi->exe = strdup(kp->p_comm);
 
-		rdi->status = RZ_DBG_PROC_STOP;
-
-		if (kp->p_psflags & PS_ZOMBIE) {
-			rdi->status = RZ_DBG_PROC_ZOMBIE;
-		} else if (kp->p_psflags & PS_STOPPED) {
+		switch (kp->p_stat) {
+		case SDEAD:
+			rdi->status = RZ_DBG_PROC_DEAD;
+			break;
+		case SSTOP:
 			rdi->status = RZ_DBG_PROC_STOP;
-		} else if (kp->p_psflags & PS_PPWAIT) {
+			break;
+		case SSLEEP:
 			rdi->status = RZ_DBG_PROC_SLEEP;
-		} else if ((kp->p_psflags & PS_EXEC) || (kp->p_psflags & PS_INEXEC)) {
+			break;
+		default:
 			rdi->status = RZ_DBG_PROC_RUN;
+			break;
 		}
 	}
 
