@@ -13,9 +13,9 @@ typedef struct {
 } RzIOMalloc;
 
 int io_memory_close(RzIODesc *fd);
-int io_memory_read(RzIO *io, RzIODesc *fd, ut8 *buf, int count);
+int io_memory_read(RzIO *io, RzIODesc *fd, ut8 *buf, size_t count);
 ut64 io_memory_lseek(RzIO *io, RzIODesc *fd, ut64 offset, int whence);
-int io_memory_write(RzIO *io, RzIODesc *fd, const ut8 *buf, int count);
+int io_memory_write(RzIO *io, RzIODesc *fd, const ut8 *buf, size_t count);
 bool io_memory_resize(RzIO *io, RzIODesc *fd, ut64 count);
 
 #endif
