@@ -4,7 +4,7 @@
 #include <rz_core.h>
 #include <errno.h>
 
-static int cmpstr(const void *_a, const void *_b) {
+static int cmpstr(const void *_a, const void *_b, void *user) {
 	const char *a = _a, *b = _b;
 	return (int)strcmp(a, b);
 }
@@ -27,7 +27,7 @@ RZ_API RZ_OWN char *rz_syscmd_sort(RZ_NONNULL const char *file) {
 			eprintf("No such file or directory\n");
 		} else {
 			list = rz_str_split_list(data, "\n", 0);
-			rz_list_sort(list, cmpstr);
+			rz_list_sort(list, cmpstr, NULL);
 			data = rz_list_to_str(list, '\n');
 			rz_list_free(list);
 		}
@@ -109,7 +109,7 @@ RZ_API RZ_OWN char *rz_syscmd_uniq(RZ_NONNULL const char *file) {
 			eprintf("No such file or directory\n");
 		} else {
 			list = rz_str_split_list(data, "\n", 0);
-			RzList *uniq_list = rz_list_uniq(list, cmpstr);
+			RzList *uniq_list = rz_list_uniq(list, cmpstr, NULL);
 			data = rz_list_to_str(uniq_list, '\n');
 			rz_list_free(uniq_list);
 			rz_list_free(list);
@@ -173,7 +173,7 @@ RZ_API RZ_OWN char *rz_syscmd_join(RZ_NONNULL const char *file1, RZ_NONNULL cons
 				}
 				rz_list_foreach (list2, iter2, str2) {
 					if (rz_str_startswith(str2, field)) {
-						char *out = rz_str_new(field);
+						char *out = rz_str_dup(field);
 						char *first = strchr(str1, ' ');
 						char *second = strchr(str2, ' ');
 						rz_str_append(out, first ? first : " ");
@@ -228,7 +228,7 @@ RZ_API RZ_OWN char *rz_syscmd_mkdir(RZ_NONNULL const char *dir) {
 
 	const char *suffix = rz_str_trim_head_ro(strchr(dir, ' '));
 	if (!suffix || !strncmp(suffix, "-p", 3)) {
-		return rz_str_dup(NULL, "Usage: mkdir [-p] [directory]\n");
+		return rz_str_dup("Usage: mkdir [-p] [directory]\n");
 	}
 	int ret;
 	char *dirname = (!strncmp(suffix, "-p ", 3))
