@@ -60,7 +60,7 @@ typedef int bool;
 
 #define mu_perror(line, message) \
 	do { \
-		printf(TBOLD TRED "ERR\n[XX] Failed to demangle line %d: " TRESET "%s\n\n", line, message); \
+		printf(TBOLD TRED "ERR\n[XX] Failed to demangle line %d: " TRESET "\n%s\n\n", line, message); \
 	} while (0)
 
 #define mu_fail(line, message) \
@@ -93,15 +93,16 @@ typedef int bool;
 		mu_assert(line, _meqstr, (act__) == NULL); \
 	} while (0)
 
-#define mu_assert_streq_free(actual, expected, line) \
+#define mu_assert_streq_free(input, actual, expected, line) \
 	do { \
 		char *act2__ = (actual); \
 		char _meqstr[MU_BUF_SIZE]; \
+		const char *inp__ = (input); \
 		const char *act__ = (actual); \
 		act__ = act__ ? act__ : "(null)"; \
 		const char *exp__ = (expected); \
 		exp__ = exp__ ? exp__ : "(null)"; \
-		snprintf(_meqstr, MU_BUF_SIZE, "expected %s, got %s.", (exp__), (act__)); \
+		snprintf(_meqstr, MU_BUF_SIZE, "expected: %s\ngot:      %s\ninput:    %s", (exp__), (act__), (inp__)); \
 		int is_success = strcmp((exp__), (act__)) == 0; \
 		free(act2__); \
 		mu_assert(line, _meqstr, is_success); \
@@ -111,19 +112,19 @@ typedef int bool;
 #define mu_demangle_func_name(name) demangle_with_##name
 #define mu_demangle_test_size(name) (sizeof(mu_demangle_test_name(name)) / sizeof((mu_demangle_test_name(name))[0]))
 
-#define mu_demangle_str_message(name, input, expected, line) \
+#define mu_demangle_str_message(name, input, expected, line, opts) \
 	do { \
-		char *output = libdemangle_handler_##name(input, RZ_DEMANGLE_OPT_ENABLE_ALL); \
+		char *output = libdemangle_handler_##name(input, opts); \
 		if (expected) { \
-			mu_assert_streq_free(output, expected, line); \
+			mu_assert_streq_free(input, output, expected, line); \
 		} else { \
 			mu_assert_null(output, input, line); \
 		} \
 	} while (0)
 
-#define mu_demangle_with(name) \
+#define mu_demangle_with(name, opts) \
 	bool mu_demangle_func_name(name)(mu_demangling_test_t * test) { \
-		mu_demangle_str_message(name, test->input, test->expected, test->line); \
+		mu_demangle_str_message(name, test->input, test->expected, test->line, opts); \
 		mu_end(test->line, test->input, test->expected); \
 	}
 
@@ -157,15 +158,15 @@ int tests_run = 0;
 int tests_passed = 0;
 int mu_test_status = MU_TEST_UNBROKEN;
 
-#define mu_main(name, demangler) \
-	mu_demangle_with(demangler); \
+#define mu_main(name, demangler, opts) \
+	mu_demangle_with(demangler, opts); \
 	int main(int argc, char **argv) { \
 		mu_demangle_loop(name, demangler); \
 		return tests_passed != tests_run; \
 	}
 
 #define mu_main2(name) \
-	mu_demangle_with(name); \
+	mu_demangle_with(name, RZ_DEMANGLE_OPT_ENABLE_ALL); \
 	int main(int argc, char **argv) { \
 		mu_demangle_loop(name, name); \
 		return tests_passed != tests_run; \
