@@ -4,6 +4,9 @@
 #include "minunit.h"
 
 mu_demangle_tests(gnu_v2,
+	// fuzzed strings
+	mu_demangle_test("_ITM_deregisterTMCCCCCCCCCCCCCCCCCCCtart__5555555555555555CloneTable", NULL),
+	// normal
 	mu_demangle_test("_vt.foo", "foo virtual table"),
 	mu_demangle_test("_vt$foo", "foo virtual table"),
 	mu_demangle_test("_vt$foo$bar", "foo::bar virtual table"),
@@ -17,7 +20,8 @@ mu_demangle_tests(gnu_v2,
 	mu_demangle_test("foo__1Ai", "A::foo(int)"),
 	mu_demangle_test("foo__1Afe", "A::foo(float,...)"),
 	mu_demangle_test("_AddColor__10ZafDisplayUcUcUcUcUc", "ZafDisplay::_AddColor(unsigned char, unsigned char, unsigned char, unsigned char, unsigned char)"),
+	mu_demangle_test("I_EEEEET_PNS0_7IsolateENS0_7Runtime10FunctionIdEPKNS2_16TSCallDescriptorENS2_7OpIndexESU_RKT0_", NULL),
 	// end
 );
 
-mu_main(gnu_v2, cxx);
\ No newline at end of file
+mu_main(gnu_v2, cxx, RZ_DEMANGLE_OPT_ENABLE_ALL);
\ No newline at end of file
