@@ -1,13 +1,15 @@
 #!/bin/sh
-# see https://github.com/cahirwpz/amigaos-cross-toolchain
+# M68K: https://github.com/bebbo/amiga-gcc
+# PPC: https://github.com/adtools/amigaos-cross-toolchain
 
+VERSION=`perl -ne 'print $1 if /^AC_INIT.*,\[([\d.]+)\],/' configure.ac`
 cat >config.h <<EOF
 #define HAVE_MKDIR 1
 #define HAVE_UTIME 1
 #define HAVE_UTIMES 1
 #define HAVE_UTIME_H 1
 #define ICONV_CONST const
-#define VERSION "1.9.1"
+#define VERSION "$VERSION"
 #define WORDS_BIGENDIAN 1
 EOF
 cp fnmatch_.h fnmatch.h
@@ -22,7 +24,7 @@ ppc-amigaos-gcc $CFLAGS -DHAVE_FSEEKO -DHAVE_ICONV -DHAVE_UMASK $SRCS -o cabextr
 ppc-amigaos-gcc $CFLAGS -DHAVE_FSEEKO src/cabinfo.c -o cabinfo &&
 lha a cabextract_OS4.lha cabextract cabinfo
 
-m68k-amigaos-gcc $CFLAGS -noixemul -DLATIN1_FILENAMES $SRCS getopt.c getopt1.c -o cabextract &&
+m68k-amigaos-gcc $CFLAGS -noixemul -DLATIN1_FILENAMES $SRCS -o cabextract &&
 m68k-amigaos-gcc $CFLAGS -noixemul src/cabinfo.c -o cabinfo &&
 lha a cabextract.lha cabextract cabinfo
 
