@@ -886,7 +886,7 @@ static RzList *_extract_regs(char *regstr, RzList *flags, char *pc_alias) {
 			for (i = regnum - rz_list_length(regs); i > 0; i--) {
 				// temporary placeholder reg. we trust the xml is correct and this will be replaced.
 				rz_list_push(regs, tmpreg);
-				rz_list_tail(regs)->data = NULL;
+				rz_list_iter_set_data(rz_list_tail(regs), NULL);
 			}
 			rz_list_push(regs, tmpreg);
 		} else {
