@@ -341,7 +341,7 @@ int all_tests() {
 
 int main(int argc, char **argv) {
 	struct timeval tv;
-	gettimeofday(&tv, NULL);
+	rz_time_gettimeofday(&tv, NULL);
 	unsigned int seed = argc > 1 ? strtoul(argv[1], NULL, 0) : tv.tv_sec + tv.tv_usec;
 	printf("seed for test_intervaltree: %u\n", seed);
 	srand(seed);
