@@ -423,16 +423,40 @@ bool test_analysis_function_noreturn_load() {
 
 Sdb *vars_ref_db() {
 	Sdb *db = sdb_new0();
-	sdb_set(db, "0x539", "{\"name\":\"hirsch\",\"bits\":64,\"type\":0,\"stack\":0,\"maxstack\":0,\"ninstr\":0,\"bp_frame\":true,\"bbs\":[],"
-			     "\"vars\":["
-			     "{\"name\":\"arg_rax\",\"type\":\"int64_t\",\"reg\":\"rax\",\"accs\":[{\"off\":3,\"type\":\"r\",\"reg\":\"rax\"},{\"off\":13,\"type\":\"rw\",\"sp\":-13,\"reg\":\"rbx\"},{\"off\":23,\"type\":\"w\",\"sp\":123,\"reg\":\"rcx\"}],\"constrs\":[0,42,1,84,2,126,3,168,4,210,5,252,6,294,7,336,8,378,9,420,10,462,11,504,12,546,13,588,14,630,15,672]},"
-			     "{\"name\":\"var_0h\",\"type\":\"const char *\",\"stack\":0,\"accs\":[{\"off\":3,\"type\":\"w\",\"sp\":321,\"reg\":\"rsp\"}]},"
-			     "{\"name\":\"var_10h\",\"type\":\"struct something\",\"stack\":-16},"
-			     "{\"name\":\"arg_8h\",\"type\":\"uint64_t\",\"stack\":8,\"cmt\":\"I have no idea what this var does\"}]}",
+	sdb_set(db, "0x539",
+		"{\"name\":\"hirsch\",\"bits\":64,\"type\":0,\"stack\":0,\"maxstack\":0,\"ninstr\":0,\"bp_frame\":true,\"bbs\":[],"
+		"\"vars\":["
+		"{\"name\":\"arg_rax\",\"type\":\"int64_t\",\"storage\":{\"type\":\"reg\",\"reg\":\"rax\"},\"accs\":[{\"off\":3,\"type\":\"r\",\"reg\":\"rax\"},{\"off\":13,\"type\":\"rw\",\"sp\":-13,\"reg\":\"rbx\"},{\"off\":23,\"type\":\"w\",\"sp\":123,\"reg\":\"rcx\"}],\"constrs\":[0,42,1,84,2,126,3,168,4,210,5,252,6,294,7,336,8,378,9,420,10,462,11,504,12,546,13,588,14,630,15,672]},"
+		"{\"name\":\"var_0h\",\"type\":\"const char *\",\"storage\":{\"type\":\"stack\",\"stack\":0},\"accs\":[{\"off\":3,\"type\":\"w\",\"sp\":321,\"reg\":\"rsp\"}]},"
+		"{\"name\":\"var_10h\",\"type\":\"struct something\",\"storage\":{\"type\":\"stack\",\"stack\":-16}},"
+		"{\"name\":\"arg_8h\",\"type\":\"uint64_t\",\"storage\":{\"type\":\"stack\",\"stack\":8},\"cmt\":\"I have no idea what this var does\"},"
+		"{\"name\":\"arg_18h\",\"type\":\"struct something\",\"storage\":{\"type\":\"composite\",\"composite\":[{\"offset_in_bits\":0,\"size_in_bits\":32,\"storage\":{\"type\":\"reg\",\"reg\":\"rax\"}},{\"offset_in_bits\":32,\"size_in_bits\":32,\"storage\":{\"type\":\"reg\",\"reg\":\"rbx\"}}]}}"
+		"]}",
 		0);
 	return db;
 }
 
+static RzAnalysisVarStorage *composite_stor(RzAnalysisVarStorage *stor) {
+	rz_analysis_var_storage_init_composite(stor);
+	RzAnalysisVarStoragePiece p1 = {
+		.offset_in_bits = 0,
+		.size_in_bits = 32,
+		.storage = RZ_NEW0(RzAnalysisVarStorage)
+	};
+	p1.storage->type = RZ_ANALYSIS_VAR_STORAGE_REG;
+	p1.storage->reg = strdup("rax");
+	RzAnalysisVarStoragePiece p2 = {
+		.offset_in_bits = 32,
+		.size_in_bits = 32,
+		.storage = RZ_NEW0(RzAnalysisVarStorage)
+	};
+	p2.storage->type = RZ_ANALYSIS_VAR_STORAGE_REG;
+	p2.storage->reg = strdup("rbx");
+	rz_vector_push(stor->composite, &p1);
+	rz_vector_push(stor->composite, &p2);
+	return stor;
+}
+
 bool test_analysis_var_save() {
 	RzAnalysis *analysis = rz_analysis_new();
 	rz_analysis_use(analysis, "x86");
@@ -485,13 +509,18 @@ bool test_analysis_var_save() {
 	v = rz_analysis_function_set_var(f, &stor, t_uint64_t, 0, "arg_8h");
 	v->comment = strdup("I have no idea what this var does");
 
+	RzAnalysisVarStorage compos = { 0 };
+	composite_stor(&compos);
+	rz_analysis_function_set_var(f, &compos, t_struct_something, 0, "arg_18h");
+
 	Sdb *db = sdb_new0();
 	rz_serialize_analysis_functions_save(db, analysis);
 
 	Sdb *expected = vars_ref_db();
-	assert_sdb_eq(db, expected, "functions save");
+	assert_sdb_json_eq(db, expected, "functions save");
 	sdb_free(db);
 	sdb_free(expected);
+
 	rz_analysis_free(analysis);
 	mu_end;
 }
@@ -510,7 +539,7 @@ bool test_analysis_var_load() {
 	RzAnalysisFunction *f = rz_analysis_get_function_at(analysis, 1337);
 	mu_assert_notnull(f, "function");
 
-	mu_assert_eq(rz_pvector_len(&f->vars), 4, "vars count");
+	mu_assert_eq(rz_pvector_len(&f->vars), 5, "vars count");
 
 	RzType *t_int64_t = rz_type_identifier_of_base_type_str(analysis->typedb, "int64_t");
 	mu_assert_notnull(t_int64_t, "has int64_t type");
@@ -589,6 +618,14 @@ bool test_analysis_var_load() {
 	mu_assert_eq(v->accesses.len, 0, "accesses count");
 	mu_assert_streq(v->comment, "I have no idea what this var does", "var comment");
 
+	RzAnalysisVarStorage compos = { 0 };
+	composite_stor(&compos);
+	v = rz_analysis_function_get_var_at(f, &compos);
+	mu_assert_notnull(v, "var");
+	mu_assert_eq(v->storage.type, RZ_ANALYSIS_VAR_STORAGE_COMPOSITE, "var storage");
+	mu_assert_streq(v->name, "arg_18h", "var name");
+	rz_analysis_var_storage_fini(&compos);
+
 	sdb_free(db);
 	rz_analysis_free(analysis);
 	mu_end;
@@ -1229,6 +1266,7 @@ static Sdb *cc_ref_db() {
 	sdb_set(db, "cc.sectarian.arg1", "rcx", 0);
 	sdb_set(db, "cc.sectarian.arg0", "rdx", 0);
 	sdb_set(db, "cc.sectarian.argn", "stack", 0);
+	sdb_set(db, "cc.sectarian.maxargs", "2", 0);
 	sdb_set(db, "sectarian", "cc", 0);
 	return db;
 }
@@ -1315,6 +1353,7 @@ Sdb *analysis_ref_db() {
 	sdb_set(cc, "cc.sectarian.arg1", "rcx", 0);
 	sdb_set(cc, "cc.sectarian.arg0", "rdx", 0);
 	sdb_set(cc, "cc.sectarian.argn", "stack", 0);
+	sdb_set(cc, "cc.sectarian.maxargs", "2", 0);
 	sdb_set(cc, "sectarian", "cc", 0);
 
 	sdb_ns(db, "types", true);
@@ -1428,9 +1467,9 @@ bool test_analysis_load() {
 	rz_vector_free(vals);
 
 	mu_assert_eq(rz_list_length(analysis->imports), 3, "imports count");
-	mu_assert_notnull(rz_list_find(analysis->imports, "pigs", (RzListComparator)strcmp), "import");
-	mu_assert_notnull(rz_list_find(analysis->imports, "dogs", (RzListComparator)strcmp), "import");
-	mu_assert_notnull(rz_list_find(analysis->imports, "sheep", (RzListComparator)strcmp), "import");
+	mu_assert_notnull(rz_list_find(analysis->imports, "pigs", (RzListComparator)strcmp, NULL), "import");
+	mu_assert_notnull(rz_list_find(analysis->imports, "dogs", (RzListComparator)strcmp, NULL), "import");
+	mu_assert_notnull(rz_list_find(analysis->imports, "sheep", (RzListComparator)strcmp, NULL), "import");
 
 	char *cc = rz_analysis_cc_get(analysis, "sectarian");
 	mu_assert_streq(cc, "rax sectarian (rdx, rcx, stack);", "get cc");
